/* Cumulative Prospect Theory Implication */
/* Bernheim - Sprenger */
/* domainfigures.do */

/* Read In Data Set*/
clear
use "`c(pwd)'/Data/bernheimsprenger.dta"


/**** BEGIN FIGURE 3 ****/
/** Figure 3: Certainty Equivalents and Equalizing Reductions */

log on
/* Estimate CPT Preference Parameters for Fitting Certainty Equivalents in Main Experiment */
nl (ceprop = (prob1^{g= 0.6} / (prob1^{g= 0.6}  + (1-prob1)^{g= 0.6})^(1/{g= 0.6}))^(1/{a=0.8}) ) if dblock ==7 & multi =="No", clu(subject)
test _b[/g] = 1
test _b[/a]=1
log off
capture drop temp
predict temp
capture drop cmodel
gen cmodel = temp*25


log on
/* Relationship Between Predicted and Actual Certainty Equivalents */
corr rmid cmodel if e(sample)
reg rmid cmodel if e(sample), clu(subject)
test cmodel = 1
test _cons = 0, accum
log off

/* Step 2: Re-estimate CPT Preference Parameters and Predict Equalizing Reductions from Eqn (3) and (4) */
nl (ceprop = (prob1^{g= 0.6} / (prob1^{g= 0.6}  + (1-prob1)^{g= 0.6})^(1/{g= 0.6}))^(1/{a=0.8}) ) if dblock ==7 & multi =="No", clu(subject)


/* Predictions and SE */
nlcom ///
(p60kupper: 18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p30kupper: 18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p10kupper: 18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p60klower: 18 -  (18^_b[a:_cons] - ((((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.10^(_b[g:_cons])/((0.10^(_b[g:_cons]) + 0.90^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p30klower: 18 -  (18^_b[a:_cons] - ((((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p10klower: 18 -  (18^_b[a:_cons] - ((((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.60^(_b[g:_cons])/((0.60^(_b[g:_cons]) + 0.40^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(diffpred60: (18 -  (18^_b[a:_cons] - ((((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.10^(_b[g:_cons])/((0.10^(_b[g:_cons]) + 0.90^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) - (18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons]))) ///
(diffpred30: (18 -  (18^_b[a:_cons] - ((((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) - (18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons]))) ///
(diffpred10: (18 -  (18^_b[a:_cons] - ((((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.60^(_b[g:_cons])/((0.60^(_b[g:_cons]) + 0.40^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) - (18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons]))) ///
,post 
est store predictedvals


capture drop covmat
matrix define covmat = e(V)

/* Generate Variable With Model Predictions */
capture drop kmod
gen kmod  =.
replace kmod = _b[p60kupper]  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 60
replace kmod = _b[p30kupper]  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 30
replace kmod = _b[p10kupper] if (x1 == 23 | x1 == 21 | x1 == 19) & p == 10


replace kmod = _b[p60klower]  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 60
replace kmod = _b[p30klower]  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 30
replace kmod = _b[p10klower]  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 10

/* Generate Variable with Model SE */
capture drop kmodse
gen kmodse = .
replace kmodse = covmat[1,1]^(1/2)  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 60
replace kmodse = covmat[2,2]^(1/2)  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 30
replace kmodse = covmat[3,3]^(1/2)  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 10
replace kmodse = covmat[4,4]^(1/2)  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 60
replace kmodse = covmat[5,5]^(1/2)  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 30
replace kmodse = covmat[6,6]^(1/2)  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 10

/* 95% Confidence Interval Limits */
capture drop kmodhigh
gen kmodhigh = kmod + 1.96*kmodse

capture drop kmodlow
gen kmodlow = kmod -1.96*kmodse

/* Predicted Differences and CI */
scalar p10pred = _b[diffpred10]
scalar p30pred = _b[diffpred30]
scalar p60pred = _b[diffpred60]
scalar p10predse = covmat[9,9]^(1/2) 
scalar p30predse = covmat[8,8]^(1/2) 
scalar p60predse = covmat[7,7]^(1/2) 


/* Panel A: Certainty Equivalents and CPT Model Fit */
xi: intreg rlow rhigh i.p if dblock == 7 & multi == "No", clu(subject)
capture drop chat
predict chat
capture drop chatse
predict chatse, stdp
capture drop chatlow
gen chatlow = chat - 1.9768*chatse
capture drop chathigh
gen chathigh = chat + 1.9768*chatse

twoway   (scatter chat p if dblock == 7, sort)   (scatteri 0 0 25 100, recast(line) lpattern(solid)) (line cmodel p ,sort lpattern(dash) lcolor(black)) (rcap chatlow chathigh p if dblock == 7)  (scatteri 0 0  2.175851 5, recast(line) lpattern(dash) lcolor(black))  (scatteri  21.62281  95 25 100, recast(line) lpattern(dash) lcolor(black)) ///
if subject == 100, xtitle("Chance of $25") ytitle("Certainty Equivalent") legend(order(1 "C"   3 "CPT Model"  2 "Risk Neutral" 4 "95% CI") row(2) ) scheme(s2mono) title("Panel A: Certainty Equivalents") 
graph save "`c(pwd)'/Output/panelA.gph", replace
graph export "`c(pwd)'/Output/panelA.pdf", replace

/* Panel B: Equalizing Reductions and CPT Model Prediction */
xi: intreg klow khigh i.p*i.x1 if dblock != 7 & dblock != 8 & multi =="No", clu(subject)
capture drop khat
predict khat
capture drop khatse
predict khatse, stdp
capture drop khatlow
gen khatlow = khat - 1.9768*khatse
capture drop khathigh
gen khathigh = khat + 1.9768*khatse
    
twoway  (rcap khatlow khathigh x1 if dblock != 7 & x1 != 25) (connected khat x1 if p == 10 & x1 != 25, sort) (connected khat x1 if p == 30 & x1 != 25,sort) (connected khat x1 if p == 60 & x1 != 25, sort)  (scatteri 0 29 11 29, recast(line) lpattern(solid)) (line kmod x1 if p == 10, sort lpattern(dash)) (line kmod x1 if p == 30,sort lpattern(dash)) (line kmod x1 if p == 60, sort lpattern(dash)) ///
(line kmodlow x1 if p == 10, sort lpattern(dot) lcolor(gray)) (line kmodhigh x1 if p == 10, sort lpattern(dot) lcolor(gray)) ///
(line kmodlow x1 if p == 30, sort lpattern(dot) lcolor(gray)) (line kmodhigh x1 if p == 30, sort lpattern(dot) lcolor(gray)) ///
(line kmodlow x1 if p == 60, sort lpattern(dot) lcolor(gray)) (line kmodhigh x1 if p == 60, sort lpattern(dot) lcolor(gray))  (scatteri 0 24 11 24, recast(line) lpattern(solid)) ///
 if subject == 100, xtitle("X" "with Y = 24, Z = 18") ytitle("Equalizing Reduction: k" "for X, Y=24+5, Z=18-k") legend(order(2 "p = 0.6"  3 "p = 0.4" 4 "p = 0.1" 1 "95% CI" 6 "CPT Pred" 9 "CPT 95% CI") row(2) )  scheme(s2mono) title("Panel B: Equalizing Reductions")
graph save "`c(pwd)'/Output/panelB.gph", replace


graph combine "`c(pwd)'/Output/panelA.gph" "`c(pwd)'/Output/panelB.gph", scheme(s2mono) xsize(15) ysize(8)
graph export "`c(pwd)'/Output/graphcombinedCPT.pdf", replace
/**** END FIGURE 3 ****/




/**** BEGIN FIGURE 4 ****/
/* Figure 4: Individual Predicted and Actual Differences in Equalizing Reductions */


/* Step 1: Create Individual Difference Measures */
/* X<Y Average Equalizing Reduction*/
capture drop belowi
capture drop temp
egen temp = mean(kmid) if dblock !=8 & dblock!=7 & x1above == 0, by(subject p)
egen belowi = mean(temp), by(subject p)

/* X > Y Average Equalizing Reduction*/
capture drop abovei
capture drop temp
egen temp = mean(kmid) if dblock !=8 & dblock!=7 & x1above == 1, by(subject p)
egen abovei = mean(temp), by(subject p)

/* Difference in Equalizing Reduction */
capture drop diffi
gen diffi = log(abovei) - log(belowi)

/* Difference in Equalizing Reduction by Probability Series */
capture drop temp
gen temp = diffi if p3 ==10
egen diffi10 = mean(temp), by(subject)

capture drop temp
gen temp = diffi if p3 ==30
egen diffi30 = mean(temp), by(subject)

capture drop temp
gen temp = diffi if p3 ==60
egen diffi60 = mean(temp), by(subject)

/* Step 2: Estimate CPT Parameters at Individual Level, Predict Out Difference Measures */
capture drop uniqid
egen uniqid = group(subject)
capture drop diffpredCEi 
gen diffpredCEi = .
capture drop diffpredERlefti 
gen diffpredERlefti = .
capture drop diffpredERrighti 
gen diffpredERrighti = .
capture drop gammaCE
gen gammaCE= .
capture drop gammaERleft
gen gammaERleft= .
capture drop gammaERright
gen gammaERright= .
capture drop convergeCE
gen convergeCE = .
capture drop convergeERleft
gen convergeERleft = .
capture drop convergeERright
gen convergeERright = .

forvalues i = 1(1)153 {
qui nl (ceprop = (prob1^{g= 0.6} / (prob1^{g= 0.6}  + (1-prob1)^{g= 0.6})^(1/{g= 0.6}))^(1/{a=0.8}) ) if dblock ==7 & uniqid == `i'
capture qui replace gammaCE = _b[g:_cons] if uniqid == `i'
capture qui replace convergeCE = e(converge) if uniqid == `i'
est clear 
capture qui replace diffpredCEi = log((0.40^(gammaCE) / ((0.40^(gammaCE) + 0.60^(gammaCE))^(1/gammaCE))) - (0.10^(gammaCE) / ((0.10^(gammaCE) + 0.90^(gammaCE))^(1/gammaCE)))) - log(0.30^(gammaCE) / ((0.30^(gammaCE) + 0.70^(gammaCE))^(1/gammaCE))) if uniqid == `i' & p3 == 60
capture qui replace diffpredCEi = log((0.70^(gammaCE) / ((0.70^(gammaCE) + 0.30^(gammaCE))^(1/gammaCE))) - (0.40^(gammaCE) / ((0.40^(gammaCE) + 0.60^(gammaCE))^(1/gammaCE)))) - log(0.30^(gammaCE) / ((0.30^(gammaCE) + 0.70^(gammaCE))^(1/gammaCE)))  if uniqid == `i' & p3 == 30
capture qui replace diffpredCEi =  log((0.90^(gammaCE) / ((0.90^(gammaCE) + 0.10^(gammaCE))^(1/gammaCE))) - (0.60^(gammaCE) / ((0.60^(gammaCE) + 0.40^(gammaCE))^(1/gammaCE)))) - log(0.30^(gammaCE) / ((0.30^(gammaCE) + 0.70^(gammaCE))^(1/gammaCE))) if uniqid == `i' & p3 == 10


capture qui nl (kmid = Z - (Z^{a=0.8}   -  (  (probY^{g2= 0.6} / ((probY^{g2= 0.6}  + (1-probY)^{g2= 0.6})^(1/{g2= 0.6}))) /(1 - (probXY^{g2= 0.6} / ((probXY^{g2= 0.6}  + (1-probXY)^{g2= 0.6})^(1/{g2= 0.6}))  )))* (Ym^{a=0.8} - Y^{a=0.8}))^(1/{a=0.8}) )  if dblock != 7 & dblock != 8  & kmid != . & x1above == 0  & uniqid == `i', iter(200)
*capture qui nl (kmid = Z - (Z^{a=0.8}   -  ((probY^{g2= 0.6} / (probY^{g2= 0.6}  + ((1-probY)^{g2= 0.6})^(1/{g2= 0.6})))/(1 - (probXY^{g2= 0.6} / (probXY^{g2= 0.6}  + (1-probXY)^{g2= 0.6})^(1/{g2= 0.6}))))* (Ym^{a=0.8} - Y^{a=0.8}))^(1/{a=0.8}) ) if dblock != 7 & dblock != 8  & kmid != . & x1above == 0  & uniqid == `i', iter(200)
capture qui replace gammaERleft = _b[g2:_cons] if uniqid == `i'
capture qui replace convergeERleft = e(converge) if uniqid == `i'
est clear 
capture qui replace diffpredERlefti = log((0.40^(gammaERleft) / ((0.40^(gammaERleft) + 0.60^(gammaERleft))^(1/gammaERleft))) - (0.10^(gammaERleft) / ((0.10^(gammaERleft) + 0.90^(gammaERleft))^(1/gammaERleft)))) - log(0.30^(gammaERleft) / ((0.30^(gammaERleft) + 0.70^(gammaERleft))^(1/gammaERleft))) if uniqid == `i' & p3 == 60
capture qui replace diffpredERlefti = log((0.70^(gammaERleft) / ((0.70^(gammaERleft) + 0.30^(gammaERleft))^(1/gammaERleft))) - (0.40^(gammaERleft) / ((0.40^(gammaERleft) + 0.60^(gammaERleft))^(1/gammaERleft)))) - log(0.30^(gammaERleft) / ((0.30^(gammaERleft) + 0.70^(gammaERleft))^(1/gammaERleft)))  if uniqid == `i' & p3 == 30
capture qui replace diffpredERlefti =  log((0.90^(gammaERleft) / ((0.90^(gammaERleft) + 0.10^(gammaERleft))^(1/gammaERleft))) - (0.60^(gammaERleft) / ((0.60^(gammaERleft) + 0.40^(gammaERleft))^(1/gammaERleft)))) - log(0.30^(gammaERleft) / ((0.30^(gammaERleft) + 0.70^(gammaERleft))^(1/gammaERleft))) if uniqid == `i' & p3 == 10


capture qui nl (kmid = Z - (Z^{a=0.8}   -  (     (   (probXY^{g3= 0.6} / ((probXY^{g3= 0.6}  + (1-probXY)^{g3= 0.6})^(1/{g3= 0.6}) ))  -   (probX^{g3= 0.6} / ((probX^{g3= 0.6}  + (1-probX)^{g3= 0.6})^(1/{g3= 0.6}))   ) )     /(1 - (probXY^{g3= 0.6} / (probXY^{g3= 0.6}  + (1-probXY)^{g3= 0.6})^(1/{g3= 0.6}))))* (Ym^{a=0.8} - Y^{a=0.8}))^(1/{a=0.8}) ) if dblock != 7 & dblock != 8 & kmid != . & x1above == 1 & uniqid == `i', iter(200)
*capture qui nl (kmid = Z - (Z^{a=0.8}   -  (     ((probXY^{g3= 0.6} / (probXY^{g3= 0.6}  + ((1-probXY)^{g3= 0.6})^(1/{g3= 0.6})))  -   (probX^{g3= 0.6} / (probX^{g3= 0.6}  + ((1-probX)^{g3= 0.6})^(1/{g3= 0.6}))) )     /(1 - (probXY^{g3= 0.6} / (probXY^{g3= 0.6}  + (1-probXY)^{g3= 0.6})^(1/{g3= 0.6}))))* (Ym^{a=0.8} - Y^{a=0.8}))^(1/{a=0.8}) ) if dblock != 7 & dblock != 8 & kmid != . & x1above == 1 & uniqid == `i', iter(200)
capture qui replace gammaERright = _b[g3:_cons] if uniqid == `i'
capture qui replace convergeERright = e(converge) if uniqid == `i'
est clear 
capture qui replace diffpredERrighti = log((0.40^(gammaERright) / ((0.40^(gammaERright) + 0.60^(gammaERright))^(1/gammaERright))) - (0.10^(gammaERright) / ((0.10^(gammaERright) + 0.90^(gammaERright))^(1/gammaERright)))) - log(0.30^(gammaERright) / ((0.30^(gammaERright) + 0.70^(gammaERright))^(1/gammaERright))) if uniqid == `i' & p3 == 60
capture qui replace diffpredERrighti = log((0.70^(gammaERright) / ((0.70^(gammaERright) + 0.30^(gammaERright))^(1/gammaERright))) - (0.40^(gammaERright) / ((0.40^(gammaERright) + 0.60^(gammaERright))^(1/gammaERright)))) - log(0.30^(gammaERright) / ((0.30^(gammaERright) + 0.70^(gammaERright))^(1/gammaERright)))  if uniqid == `i' & p3 == 30
capture qui replace diffpredERrighti =  log((0.90^(gammaERright) / ((0.90^(gammaERright) + 0.10^(gammaERright))^(1/gammaERright))) - (0.60^(gammaERright) / ((0.60^(gammaERright) + 0.40^(gammaERright))^(1/gammaERright)))) - log(0.30^(gammaERright) / ((0.30^(gammaERright) + 0.70^(gammaERright))^(1/gammaERright))) if uniqid == `i' & p3 == 10
est clear

disp `i'


}




/* Predicted Difference in Equalizing Reduction by Probability Series */
capture drop temp
gen temp = diffpredCEi if p3 ==10
capture drop diffpredi10
egen diffpredi10 = mean(temp), by(uniqid)

capture drop temp
gen temp = diffpredCEi if p3 ==30
capture drop diffpredi30
egen diffpredi30 = mean(temp), by(uniqid)

capture drop temp
gen temp = diffpredCEi if p3 ==60
capture drop diffpredi60
egen diffpredi60 = mean(temp), by(uniqid)

/* Cut and Clean for Histogram */
capture drop diffgroup
egen diffgroup = cut(diffi), at(-10(0.1)10)
capture drop diffpredgroup
egen diffpredgroup = cut(diffpredCEi), at(-10(0.1)10) 
capture drop temp
gen temp = diffpredgroup + .06

/* Labels for Probability Series */
capture label drop p3lab
label define p3lab 10 "p = 0.60" 30 "p = 0.40" 60 "p = 0.10"
label values p3 p3lab

/* Panel A: Predicted and Actual Histograms */

twoway (histogram diffgroup , percent discrete fcolor(gs8) lcolor(gs8) barwidth(0.04) gap(1)) (histogram temp, percent discrete fcolor(black) lcolor(black) barwidth(0.04) gap(1))  if diffi <= 5 & diffi >= -5 & multi == "No" & dblock == 1 & diffpredCEi!=. , by(p3, cols(1) note("") title("Panel A: Predicted and Actual Distributions")) scheme(s2mono) legend(order(1 "Actual {&Delta}log(k)" 2 "Predicted {&Delta}log(w{sub:Y}/w{sub:Z})"))  xtitle("Log Difference") 
graph save "`c(pwd)'/Output/panelA.gph", replace

/* Panel B: Predicted and Actual Relationship */
twoway (scatter  diffi  diffpredCEi , col(gs4)) if diffi <= 5 & diffi >= -5 & multi == "No" & dblock == 1 &diffpredCEi!= ., by(p3, cols(1) note("") title("Panel B: Predicted and Actual Relationship")) scheme(s2mono) xtitle("Predicted {&Delta}log(w{sub:Y}/w{sub:Z})") ytitle("Actual {&Delta}log(k)") 
graph save "`c(pwd)'/Output/panelB.gph", replace

graph combine "`c(pwd)'/Output/panelA.gph" "`c(pwd)'/Output/panelB.gph", scheme(s2mono) row(1) xsize(11) ysize(7)
graph export "`c(pwd)'/Output/individualgraph.pdf", replace




log on 
/* Additional Individual Statistics (fn 48-50) related to Figure 4*/
su diffpredCEi diffi if dblock == 1&  convergeCE == 1 & multi == "No" & p3 == 10, det
su diffpredCEi diffi if dblock == 1&  convergeCE == 1 & multi == "No" & p3 == 30, det
su diffpredCEi diffi if dblock == 1&  convergeCE == 1 & multi == "No" & p3 == 60, det

signrank diffpredCEi = diffi if dblock == 1&  convergeCE == 1 & multi == "No" & p3 == 10
signrank diffpredCEi = diffi if dblock == 1&  convergeCE == 1 & multi == "No" & p3 == 30
signrank diffpredCEi = diffi if dblock == 1&  convergeCE == 1 & multi == "No" & p3 == 60

pwcorr diffpredCEi diffi if dblock == 1&  convergeCE == 1 & multi == "No" & p3 == 10, sig
pwcorr diffpredCEi diffi if dblock == 1&  convergeCE == 1 & multi == "No" & p3 == 30, sig
pwcorr diffpredCEi diffi if dblock == 1&  convergeCE == 1 & multi == "No" & p3 == 60, sig


capture drop temp
gen temp = (diffpredERlefti == . | diffpredERrighti == . | convergeERleft == 0 | convergeERright == 0 | diffpredERleft > 10)
capture drop temp2
egen temp2 = total(temp) if dblock == 1, by(subject)

su diffi diffpredCEi diffpredERlefti diffpredERrighti if dblock == 1&  temp2 == 0 & multi == "No"

corr diffi diffpredCEi diffpredERlefti diffpredERrighti if dblock == 1&  temp2 == 0 & multi == "No" 
log off 

/**** END FIGURE 4 ****/


/*** BEGIN APPENDIX FIGURE WITH ALT BENCHMARKS ***/
/***** Figure With RHS Predicted from LHS ***/
nl (kmid = Z - (Z^{a=0.8}   -  (  (probY^{g= 0.6} / ((probY^{g= 0.6}  + (1-probY)^{g= 0.6})^(1/{g= 0.6}))) /(1 - (probXY^{g= 0.6} / ((probXY^{g= 0.6}  + (1-probXY)^{g= 0.6})^(1/{g= 0.6}))  )))* (Ym^{a=0.8} - Y^{a=0.8}))^(1/{a=0.8}) ) if dblock != 7 & dblock != 8 & multi == "No" & kmid != . & x1above == 0, clu(subject)

/* Predictions and SE */
nlcom ///
(p60kupper: 18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p30kupper: 18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p10kupper: 18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p60klower: 18 -  (18^_b[a:_cons] - ((((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.10^(_b[g:_cons])/((0.10^(_b[g:_cons]) + 0.90^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p30klower: 18 -  (18^_b[a:_cons] - ((((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p10klower: 18 -  (18^_b[a:_cons] - ((((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.60^(_b[g:_cons])/((0.60^(_b[g:_cons]) + 0.40^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(diffpred60: (18 -  (18^_b[a:_cons] - ((((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.10^(_b[g:_cons])/((0.10^(_b[g:_cons]) + 0.90^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) - (18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons]))) ///
(diffpred30: (18 -  (18^_b[a:_cons] - ((((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) - (18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons]))) ///
(diffpred10: (18 -  (18^_b[a:_cons] - ((((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.60^(_b[g:_cons])/((0.60^(_b[g:_cons]) + 0.40^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) - (18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons]))) ///
,post 
est store predictedvals

capture drop covmat
matrix define covmat = e(V)


/* Generate Variable With Model Predictions */
capture drop kmod
gen kmod  =.
replace kmod = _b[p60kupper]  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 60
replace kmod = _b[p30kupper]  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 30
replace kmod = _b[p10kupper] if (x1 == 23 | x1 == 21 | x1 == 19) & p == 10


replace kmod = _b[p60klower]  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 60
replace kmod = _b[p30klower]  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 30
replace kmod = _b[p10klower]  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 10

/* Generate Variable with Model SE */
capture drop kmodse
gen kmodse = .
replace kmodse = covmat[1,1]^(1/2)  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 60
replace kmodse = covmat[2,2]^(1/2)  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 30
replace kmodse = covmat[3,3]^(1/2)  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 10
replace kmodse = covmat[4,4]^(1/2)  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 60
replace kmodse = covmat[5,5]^(1/2)  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 30
replace kmodse = covmat[6,6]^(1/2)  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 10

/* 95% Confidence Interval Limits */
capture drop kmodhigh
gen kmodhigh = kmod + 1.96*kmodse

capture drop kmodlow
gen kmodlow = kmod -1.96*kmodse

/* Panel B: Equalizing Reductions and CPT Model Prediction */
xi: intreg klow khigh i.p*i.x1 if dblock != 7 & dblock != 8 & multi =="No", clu(subject)
capture drop khat
predict khat
capture drop khatse
predict khatse, stdp
capture drop khatlow
gen khatlow = khat - 1.9768*khatse
capture drop khathigh
gen khathigh = khat + 1.9768*khatse
    
twoway  (rcap khatlow khathigh x1 if dblock != 7 & x1 != 25) (connected khat x1 if p == 10 & x1 != 25, sort) (connected khat x1 if p == 30 & x1 != 25,sort) (connected khat x1 if p == 60 & x1 != 25, sort)  (scatteri 0 29 11 29, recast(line) lpattern(solid)) (line kmod x1 if p == 10, sort lpattern(dash)) (line kmod x1 if p == 30,sort lpattern(dash)) (line kmod x1 if p == 60, sort lpattern(dash)) ///
(line kmodlow x1 if p == 10, sort lpattern(dot) lcolor(gray)) (line kmodhigh x1 if p == 10, sort lpattern(dot) lcolor(gray)) ///
(line kmodlow x1 if p == 30, sort lpattern(dot) lcolor(gray)) (line kmodhigh x1 if p == 30, sort lpattern(dot) lcolor(gray)) ///
(line kmodlow x1 if p == 60, sort lpattern(dot) lcolor(gray)) (line kmodhigh x1 if p == 60, sort lpattern(dot) lcolor(gray))  (scatteri 0 24 11 24, recast(line) lpattern(solid)) ///
 if subject == 100, xtitle("X" "with Y = 24, Z = 18") ytitle("Equalizing Reduction: k" "for X, Y=24+5, Z=18-k") legend(order(2 "p = 0.6"  3 "p = 0.4" 4 "p = 0.1" 1 "95% CI" 6 "CPT Pred" 9 "CPT 95% CI") row(2) )  scheme(s2mono) title("Panel A" "CPT Fit Y>X>Z")
graph save "`c(pwd)'/Output/panelA.gph", replace


/***** Figure With LHS Predicted from RHS ***/
nl (kmid = Z - (Z^{a=0.8}   -  (     (   (probXY^{g= 0.6} / ((probXY^{g= 0.6}  + (1-probXY)^{g= 0.6})^(1/{g= 0.6}) ))  -   (probX^{g= 0.6} / ((probX^{g= 0.6}  + (1-probX)^{g= 0.6})^(1/{g= 0.6}))   ) )     /(1 - (probXY^{g= 0.6} / (probXY^{g= 0.6}  + (1-probXY)^{g= 0.6})^(1/{g= 0.6}))))* (Ym^{a=0.8} - Y^{a=0.8}))^(1/{a=0.8}) ) if dblock != 7 & dblock != 8 & multi == "No" & kmid != . & x1above == 1, clu(subject)

/* Predictions and SE */
nlcom ///
(p60kupper: 18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p30kupper: 18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p10kupper: 18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p60klower: 18 -  (18^_b[a:_cons] - ((((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.10^(_b[g:_cons])/((0.10^(_b[g:_cons]) + 0.90^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p30klower: 18 -  (18^_b[a:_cons] - ((((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(p10klower: 18 -  (18^_b[a:_cons] - ((((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.60^(_b[g:_cons])/((0.60^(_b[g:_cons]) + 0.40^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) ///
(diffpred60: (18 -  (18^_b[a:_cons] - ((((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.10^(_b[g:_cons])/((0.10^(_b[g:_cons]) + 0.90^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) - (18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons]))) ///
(diffpred30: (18 -  (18^_b[a:_cons] - ((((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) - (18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons]))) ///
(diffpred10: (18 -  (18^_b[a:_cons] - ((((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) ) - ((0.60^(_b[g:_cons])/((0.60^(_b[g:_cons]) + 0.40^(_b[g:_cons]))^(1/_b[g:_cons]))) ))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))) )))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons])) - (18 -  (18^_b[a:_cons] - (((0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))))/(1-((0.90^(_b[g:_cons])/((0.90^(_b[g:_cons]) + 0.10^(_b[g:_cons]))^(1/_b[g:_cons]))))))*(29^_b[a:_cons] - 24^_b[a:_cons]))^(1/_b[a:_cons]))) ///
,post 
est store predictedvals

capture drop covmat
matrix define covmat = e(V)


/* Generate Variable With Model Predictions */
capture drop kmod
gen kmod  =.
replace kmod = _b[p60kupper]  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 60
replace kmod = _b[p30kupper]  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 30
replace kmod = _b[p10kupper] if (x1 == 23 | x1 == 21 | x1 == 19) & p == 10


replace kmod = _b[p60klower]  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 60
replace kmod = _b[p30klower]  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 30
replace kmod = _b[p10klower]  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 10

/* Generate Variable with Model SE */
capture drop kmodse
gen kmodse = .
replace kmodse = covmat[1,1]^(1/2)  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 60
replace kmodse = covmat[2,2]^(1/2)  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 30
replace kmodse = covmat[3,3]^(1/2)  if (x1 == 23 | x1 == 21 | x1 == 19) & p == 10
replace kmodse = covmat[4,4]^(1/2)  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 60
replace kmodse = covmat[5,5]^(1/2)  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 30
replace kmodse = covmat[6,6]^(1/2)  if (x1 == 34 | x1 == 32 | x1 == 30) & p == 10

/* 95% Confidence Interval Limits */
capture drop kmodhigh
gen kmodhigh = kmod + 1.96*kmodse

capture drop kmodlow
gen kmodlow = kmod -1.96*kmodse

/* Panel B: Equalizing Reductions and CPT Model Prediction */
xi: intreg klow khigh i.p*i.x1 if dblock != 7 & dblock != 8 & multi =="No", clu(subject)
capture drop khat
predict khat
capture drop khatse
predict khatse, stdp
capture drop khatlow
gen khatlow = khat - 1.9768*khatse
capture drop khathigh
gen khathigh = khat + 1.9768*khatse
    
twoway  (rcap khatlow khathigh x1 if dblock != 7 & x1 != 25) (connected khat x1 if p == 10 & x1 != 25, sort) (connected khat x1 if p == 30 & x1 != 25,sort) (connected khat x1 if p == 60 & x1 != 25, sort)  (scatteri 0 29 11 29, recast(line) lpattern(solid)) (line kmod x1 if p == 10, sort lpattern(dash)) (line kmod x1 if p == 30,sort lpattern(dash)) (line kmod x1 if p == 60, sort lpattern(dash)) ///
(line kmodlow x1 if p == 10, sort lpattern(dot) lcolor(gray)) (line kmodhigh x1 if p == 10, sort lpattern(dot) lcolor(gray)) ///
(line kmodlow x1 if p == 30, sort lpattern(dot) lcolor(gray)) (line kmodhigh x1 if p == 30, sort lpattern(dot) lcolor(gray)) ///
(line kmodlow x1 if p == 60, sort lpattern(dot) lcolor(gray)) (line kmodhigh x1 if p == 60, sort lpattern(dot) lcolor(gray))  (scatteri 0 24 11 24, recast(line) lpattern(solid)) ///
 if subject == 100, xtitle("X" "with Y = 24, Z = 18") ytitle("Equalizing Reduction: k" "for X, Y=24+5, Z=18-k") legend(order(2 "p = 0.6"  3 "p = 0.4" 4 "p = 0.1" 1 "95% CI" 6 "CPT Pred" 9 "CPT 95% CI") row(2) )  scheme(s2mono) title("Panel B" "CPT Fit X>Y>Z")
graph save "`c(pwd)'/Output/panelB.gph", replace

grc1leg "`c(pwd)'/Output/panelA.gph" "`c(pwd)'/Output/panelB.gph", scheme(s2mono) xsize(15) ysize(8) ycommon
graph export "`c(pwd)'/Output/graphCPTLR.pdf", replace

/*** END APPENDIX FIGURE ALT BENCHMARKS ***/

