/* Cumulative Prospect Theory Implication */
/* Bernheim - Sprenger */
/* domodifieder.do */

/* Read In Data Set*/
clear
use "`c(pwd)'/Data/modifieder.dta"



/*** BEGIN FIGURE  5 ****/
/*** NOTE: PREDICTED VALUES CALCULATED IN R ***/
log on
/* Estimate CPT on Certainty Equivalents in Modified ER Experiment */ 

gen valprop = cemid/25
nl (valprop = (p^{g= 0.6} / (p^{g= 0.6}  + (1-p)^{g= 0.6})^(1/{g= 0.6}))^(1/{a=0.8}) ) if series == 3 & mswitcher == 0, clu(uniqid)
test _b[/g] = 1
test _b[/a]=1
log off
capture drop temp
predict temp
capture drop valmodel
gen valmodel = temp*25

su valmodel if p > 0.04 & p < 0.06
scalar pred5 = r(mean)
 
su valmodel if p > 0.94 & p < 0.96
scalar pred95 = r(mean)

/* Estimate EU on Certainty Equivalents */
nl (valprop = p^(1/{a=0.8}) ) if series == 3 & mswitcher == 0, clu(uniqid)


/* Average Data  */
capture drop eqredhightemp
gen eqredhightemp = eqredhigh
replace eqredhightemp = . if r==40 & task <= 18 & ns == 1

xi: intreg eqred eqredhightemp i.val*i.series if series != 3 & mswitcher == 0, clu(uniqid)
capture drop eqredhat
predict eqredhat if e(sample), xb
capture drop temp
predict temp if e(sample), stdp
capture drop eqredhatlow
gen eqredhatlow = eqredhat -1.96*temp
capture drop eqredhathigh
gen eqredhathigh = eqredhat + 1.96*temp


capture drop celowtemp
gen celowtemp = celow
replace celowtemp = . if celow == 0 & ns == 1 & task > 18

xi: intreg celowtemp ce i.p if series == 3 & mswitcher == 0, clu(uniqid)
capture drop cehat
predict cehat if e(sample), xb
capture drop temp
predict temp if e(sample), stdp
capture drop cehatlow
gen cehatlow = cehat -1.96*temp
capture drop cehathigh
gen cehathigh = cehat + 1.96*temp

twoway (scatter cehat p, sort) (rcap cehathigh cehatlow p, lcolor(gray))  (line valmodel p, sort lcolor(black) lpattern(dash)) ///
 (scatteri 0 0     2.226704   0.05, recast(line) lcolor(black) lpattern(dash)) ///
  (scatteri 25 1        22.16713      0.95, recast(line) lcolor(black) lpattern(dash)) ///
(scatteri 0 0 25 1, recast(line) lcolor(black) lpattern(solid)) if uniqid == 1 ///
, ytitle(Certainty Equivalents) title("Panel A: Certainty Equivalents") xtitle("Probability") legend(order(1 "C" 2 " 95% CI" 3 "CPT Model Fit")) scheme(s2mono)
graph save "`c(pwd)'/Output/panelA.gph", replace


twoway (rcap eqredhathigh eqredhatlow val, lcolor(gray)) (connected eqredhat val if series == 1, sort) (connected eqredhat val if series == 2, sort) ///
(scatteri 6.17 1 6.13 2 6.10 3 6.08 4 6.06 5 6.05 6 6.04 7 6.02 8 5.77 9  5.51 10 ///
 5.26 11 5.01 12  4.76 13  4.52 14 4.27 15 4.02 16 3.77 17  3.53 18  3.52 19 3.52 20 ///
 3.52 21  3.51 22 3.51 23 3.51 24 3.51 25 3.50 26 3.50 27 3.50 29  3.59 29  3.76  30 ///
 3.94 31 4.12 32 4.30 33 4.48 34 4.65 35 4.83 36 4.83 37  4.83 38  4.82 39 4.82 40, recast(line) lcolor(black) lpattern(dash) ) ///
(scatteri 3.41 1 3.39 2 3.38 3 3.36 4 3.35 5 3.35 6 3.34 7 3.33 8 3.33 9 3.32 10 ///
  3.25 11 3.03 12 2.81 13 2.59 14 2.37 15  2.15 16  1.94 17  1.72 18  1.72 19 1.72 20 ///
  1.71 21 1.71 22 1.71 23 1.71 24 1.71 25  1.71 26  1.71 27 1.71 28 1.71 29 1.70 30  ///
  1.82 31 1.99 32 2.16 33 2.33 34 2.50 35 2.67 36 2.67 37  2.67 38 2.67 39 2.67 40 ,  recast(line) lcolor(black) lpattern(dash)) ///
 if uniqid == 1, ///
 ytitle(Modified Equalizing Reduction) title("Panel B: Modified" "Equalizing Reductions") xtitle("X" "with Y = 36, Z = 18") legend(order(2 "p = 0.4" 3 "p = 0.6" 1 "95% CI" 4 "CPT Prediction")) scheme(s2mono)
graph save "`c(pwd)'/Output/panelB.gph", replace

graph combine "`c(pwd)'/Output/panelA.gph" "`c(pwd)'/Output/panelB.gph", scheme(s2mono)
graph export "`c(pwd)'/Output/modifieder.pdf", replace

/*** END FIGURE 5 ***/

/*** BEGIN FIGURE A6 ***/
/*** NOTE: PREDICTED VALUES CALCULATED IN R ***/
/* Alternative Benchmarks for Appendix Figure */
/* Estimating Equation 6, 7, 8 and Feed to R for Prediction */
/* Eq. 6 */
twoway (rcap eqredhathigh eqredhatlow val, lcolor(gray)) (connected eqredhat val if series == 1, sort) (connected eqredhat val if series == 2, sort) ///
(scatteri    4.49  1.00  4.26  2.00  4.11  3.00  3.99  4.00  3.89  5.00  3.81  6.00  3.74  7.00  3.68 ///
  8.00  3.63  9.00  3.58 10.00  3.42 11.00  3.19 12.00  2.95 13.00  2.73 14.00  2.50 15.00 ///
 2.28 16.00  2.06 17.00  1.84 18.00  1.83 19.00  1.81 20.00  1.80 21.00  1.79 22.00  1.78 ///
 23.00  1.77 24.00  1.76 25.00  1.75 26.00  1.74 27.00  1.73 28.00  1.72 29.00  1.71 30.00 ///
 1.81 31.00  1.95 32.00  2.08 33.00  2.22 34.00  2.36 35.00  2.50 36.00  2.49 37.00  2.48 ///
 38.00  2.47 39.00  2.46 40.00, recast(line) lcolor(black) lpattern(dash) ) ///
(scatteri    8.18  1.00  7.78  2.00  7.50  3.00  7.28  4.00  7.11  5.00  6.96  6.00  6.83  7.00  6.55 ///
 8.00  6.25  9.00  5.95 10.00  5.66 11.00  5.37 12.00  5.10 13.00  4.82 14.00  4.56 15.00 /// 
  4.29 16.00  4.03 17.00  3.78 18.00  3.75 19.00  3.72 20.00  3.70 21.00  3.67 22.00  3.65 /// 
 23.00  3.63 24.00  3.61 25.00  3.59 26.00  3.57 27.00  3.55 28.00  3.61 29.00  3.75 30.00 ///
 3.89 31.00  4.02 32.00  4.16 33.00  4.29 34.00  4.43 35.00  4.56 36.00  4.55 37.00  4.53 ///
 38.00  4.51 39.00  4.49 40.00 ,  recast(line) lcolor(black) lpattern(dash)) ///
 if uniqid == 1, ///
 ytitle(Modified Equalizing Reduction) title("Panel A" "CPT Estimated" "X>Y>Z") xtitle("X" "with Y = 36, Z = 18") legend(order(2 "p = 0.4" 3 "p = 0.6" 1 "95% CI" 4 "CPT Prediction")) scheme(s2mono)
graph save "`c(pwd)'/Output/panelC.gph", replace

/* Eq 7 */
twoway (rcap eqredhathigh eqredhatlow val, lcolor(gray)) (connected eqredhat val if series == 1, sort) (connected eqredhat val if series == 2, sort) ///
(scatteri    9.20  1.00  7.73  2.00  6.82  3.00  6.17  4.00  5.67  5.00  5.28  6.00  4.95  7.00  4.68 /// 
  8.00  4.45  9.00  4.21 10.00  3.92 11.00  3.64 12.00  3.39 13.00  3.14 14.00  2.92 15.00 ///
  2.70 16.00  2.49 17.00  2.29 18.00  2.23 19.00  2.18 20.00  2.13 21.00  2.08 22.00  2.03 ///
 23.00  1.99 24.00  1.95 25.00  1.91 26.00  1.87 27.00  1.84 28.00  1.80 29.00  1.77 30.00 ///
 1.80 31.00  1.85 32.00  1.90 33.00  1.95 34.00  2.00 35.00  2.05 36.00  2.02 37.00  1.99 ///
38.00  1.96 39.00  1.94 40.00, recast(line) lcolor(black) lpattern(dash) ) ///
(scatteri    15.09  1.00 13.31  2.00 12.02  3.00 11.01  4.00 10.18  5.00  9.48  6.00  8.86  7.00  8.31 ///
  8.00  7.82  9.00  7.37 10.00  6.96 11.00  6.58 12.00  6.22 13.00  5.89 14.00  5.57 15.00 ///
 5.28 16.00  4.99 17.00  4.72 18.00  4.60 19.00  4.49 20.00  4.39 21.00  4.29 22.00  4.20 ///
 23.00  4.11 24.00  4.03 25.00  3.95 26.00  3.88 27.00  3.81 28.00  3.81 29.00  3.82 30.00 ///
 3.84 31.00  3.86 32.00  3.88 33.00  3.90 34.00  3.93 35.00  3.95 36.00  3.90 37.00  3.85 ///
 38.00  3.79 39.00  3.75 40.00 ,  recast(line) lcolor(black) lpattern(dash)) ///
 if uniqid == 1, ///
 ytitle(Modified Equalizing Reduction) title("Panel B" "CPT Estimated" "Y>X'>Z") xtitle("X" "with Y = 36, Z = 18") legend(order(2 "p = 0.4" 3 "p = 0.6" 1 "95% CI" 4 "CPT Prediction")) scheme(s2mono)
graph save "`c(pwd)'/Output/panelD.gph", replace


/* Eq 8 */
twoway (rcap eqredhathigh eqredhatlow val, lcolor(gray)) (connected eqredhat val if series == 1, sort) (connected eqredhat val if series == 2, sort) ///
(scatteri    2.93  1.00  3.00  2.00  3.05  3.00  3.08  4.00  3.12  5.00  3.15  6.00  3.17  7.00  3.19 /// 
  8.00  3.21  9.00  3.23 10.00  3.19 11.00  2.97 12.00  2.74 13.00  2.51 14.00  2.28 15.00 ///
  2.05 16.00  1.82 17.00  1.59 18.00  1.60 19.00  1.60 20.00  1.61 21.00  1.61 22.00  1.62 ///
23.00  1.62 24.00  1.62 25.00  1.63 26.00  1.63 27.00  1.64 28.00  1.64 29.00  1.64 30.00 ///
  1.77 31.00  1.97 32.00  2.17 33.00  2.37 34.00  2.57 35.00  2.77 36.00  2.77 37.00  2.78 ///
 38.00  2.78 39.00  2.79 40.00, recast(line) lcolor(black) lpattern(dash) ) ///
(scatteri    5.18  1.00  5.30  2.00  5.38  3.00  5.45  4.00  5.51  5.00  5.56  6.00  5.60  7.00  5.64 /// 
  8.00  5.50  9.00  5.26 10.00  5.01 11.00  4.77 12.00  4.52 13.00  4.27 14.00  4.01 15.00 ///
 3.76 16.00  3.50 17.00  3.24 18.00  3.25 19.00  3.26 20.00  3.27 21.00  3.28 22.00  3.29 ///
 23.00  3.30 24.00  3.31 25.00  3.32 26.00  3.32 27.00  3.33 28.00  3.41 29.00  3.62 30.00 ///
3.83 31.00  4.05 32.00  4.26 33.00  4.47 34.00  4.69 35.00  4.90 36.00  4.91 37.00  4.92 ///
 38.00  4.93 39.00  4.93 40.00,  recast(line) lcolor(black) lpattern(dash)) ///
 if uniqid == 1, ///
 ytitle(Modified Equalizing Reduction) title("Panel C" "CPT Estimated" "Y>Z>X''") xtitle("X" "with Y = 36, Z = 18") legend(order(2 "p = 0.4" 3 "p = 0.6" 1 "95% CI" 4 "CPT Prediction")) scheme(s2mono)
graph save "`c(pwd)'/Output/panelE.gph", replace


grc1leg "`c(pwd)'/Output/panelC.gph" "`c(pwd)'/Output/panelD.gph" "`c(pwd)'/Output/panelE.gph", scheme(s2mono) row(1) xsize(18) ysize(5)
graph export "`c(pwd)'/Output/modifiederx3.pdf", replace
/*** END FIGURE A6 ***/



/*** BEGIN ANALYSIS FOOTNOTE 60 and MIXTURE ***/
/* Write an Estimator for CPT in Modified ER */
capture drop probX
capture drop probY
capture drop probZ
capture drop probXY
capture drop probZY

gen probX = 0.4
replace probX = 0.6 if series == 2
replace probX = . if series == 3
gen probY = (1-probX)/2
gen probZ = (1-probX)/2
gen probXY = probX + probY
gen probZY = probZ + probY

capture drop Y
gen Y = 36
capture drop Z
gen Z = 18
capture drop m
gen m = 4
capture drop X 
gen X = val

capture drop Xhigh
gen Xhigh = 0
replace Xhigh = 1 if X > Y

capture drop Xmid
gen Xmid = 0 
replace Xmid = 1 if Y>X & X> Z

capture drop Xlow
gen Xlow = 0
replace Xlow = 1 if X < Z

log on
/*** ANALYSIS FOOTNOTE 60 and MIXTURE ***/
/* Equation 6*/
nl 	(eqredmid = ( (probX^{g= 0.6} / ((probX^{g= 0.6}  + (1-probX)^{g= 0.6})^(1/{g= 0.6})))  *({alpha=0.8}*(X^({alpha=0.8} -1)))*m) / ///
	( ///
	((probXY^{g= 0.6} / ((probXY^{g= 0.6}  + (1-probXY)^{g= 0.6})^(1/{g= 0.6}))) -  (probX^{g= 0.6} / ((probX^{g= 0.6}  + (1-probX)^{g= 0.6})^(1/{g= 0.6}))))*({alpha=0.8}*(Y^({alpha=0.8} -1)))   + ///
	(1 - (probXY^{g= 0.6} / ((probXY^{g= 0.6}  + (1-probXY)^{g= 0.6})^(1/{g= 0.6}))))*({alpha=0.8}*(Z^({alpha=0.8} -1))) 	 ///
	) ///	
	) if series != 3 & mswitcher == 0 & Xhigh == 1,	clu(uniqid)
	 

/* Equation 7 */
nl (eqredmid = ( (  (probXY^{g= 0.6} / ((probXY^{g= 0.6}  + (1-probXY)^{g= 0.6})^(1/{g= 0.6}))) - (probY^{g= 0.6} / ((probY^{g= 0.6}  + (1-probY)^{g= 0.6})^(1/{g= 0.6})))  )        *({alpha=0.8}*(X^({alpha=0.8} -1)))*m) / ///
	( ///
	(probY^{g= 0.6} / ((probY^{g= 0.6}  + (1-probY)^{g= 0.6})^(1/{g= 0.6})))*({alpha=0.8}*(Y^({alpha=0.8} -1)))   + ///
	(1 - (probXY^{g= 0.6} / ((probXY^{g= 0.6}  + (1-probXY)^{g= 0.6})^(1/{g= 0.6}))))*({alpha=0.8}*(Z^({alpha=0.8} -1))) 	 ///
	) ///	
	 ) if series != 3 & mswitcher == 0	 & Xmid == 1,	clu(uniqid)
	 

/* Equation 8 */
nl 	(eqredmid = (    (1 - (probZY^{g= 0.6} / ((probZY^{g= 0.6}  + (1-probZY)^{g= 0.6})^(1/{g= 0.6}))) )     *({alpha=0.8}*(X^({alpha=0.8} -1)))*m) / ///
	( ///
	(probY^{g= 0.6} / ((probY^{g= 0.6}  + (1-probY)^{g= 0.6})^(1/{g= 0.6})))*({alpha=0.8}*(Y^({alpha=0.8} -1)))   + ///
	(  (probZY^{g= 0.6} / ((probZY^{g= 0.6}  + (1-probZY)^{g= 0.6})^(1/{g= 0.6}))) - (probY^{g= 0.6} / ((probY^{g= 0.6}  + (1-probY)^{g= 0.6})^(1/{g= 0.6})))  )*({alpha=0.8}*(Z^({alpha=0.8} -1))) 	 ///
	) ///		 
	) if series != 3 & mswitcher == 0	 & Xlow == 1,	clu(uniqid)
log off









log on
/* Combined CPT/OPT  Estimator */
nl 	(eqredmid = ///
{delta=0.1}* ( ///
Xhigh*( /// 
	( (probX^{g= 0.6} / ((probX^{g= 0.6}  + (1-probX)^{g= 0.6})^(1/{g= 0.6})))  *({alpha=0.8}*(X^({alpha=0.8} -1)))*m) / ///
	( ///
	((probXY^{g= 0.6} / ((probXY^{g= 0.6}  + (1-probXY)^{g= 0.6})^(1/{g= 0.6}))) -  (probX^{g= 0.6} / ((probX^{g= 0.6}  + (1-probX)^{g= 0.6})^(1/{g= 0.6}))))*({alpha=0.8}*(Y^({alpha=0.8} -1)))   + ///
	(1 - (probXY^{g= 0.6} / ((probXY^{g= 0.6}  + (1-probXY)^{g= 0.6})^(1/{g= 0.6}))))*({alpha=0.8}*(Z^({alpha=0.8} -1))) 	 ///
	) ///			
	) ///
+ Xmid*( /// 
	( (  (probXY^{g= 0.6} / ((probXY^{g= 0.6}  + (1-probXY)^{g= 0.6})^(1/{g= 0.6}))) - (probY^{g= 0.6} / ((probY^{g= 0.6}  + (1-probY)^{g= 0.6})^(1/{g= 0.6})))  )        *({alpha=0.8}*(X^({alpha=0.8} -1)))*m) / ///
	( ///
	(probY^{g= 0.6} / ((probY^{g= 0.6}  + (1-probY)^{g= 0.6})^(1/{g= 0.6})))*({alpha=0.8}*(Y^({alpha=0.8} -1)))   + ///
	(1 - (probXY^{g= 0.6} / ((probXY^{g= 0.6}  + (1-probXY)^{g= 0.6})^(1/{g= 0.6}))))*({alpha=0.8}*(Z^({alpha=0.8} -1))) 	 ///
	) ///	
	) ///
+ Xlow*( ///
	( (1 - (probZY^{g= 0.6} / ((probZY^{g= 0.6}  + (1-probZY)^{g= 0.6})^(1/{g= 0.6}))) )     *({alpha=0.8}*(X^({alpha=0.8} -1)))*m) / ///
	( ///
	(probY^{g= 0.6} / ((probY^{g= 0.6}  + (1-probY)^{g= 0.6})^(1/{g= 0.6})))*({alpha=0.8}*(Y^({alpha=0.8} -1)))   + ///
	(  (probZY^{g= 0.6} / ((probZY^{g= 0.6}  + (1-probZY)^{g= 0.6})^(1/{g= 0.6}))) - (probY^{g= 0.6} / ((probY^{g= 0.6}  + (1-probY)^{g= 0.6})^(1/{g= 0.6})))  )*({alpha=0.8}*(Z^({alpha=0.8} -1))) 	 ///
	) ///	
	) /// 
) ///
+ (1-{delta=0.1})* ( ///
	(((probX^{g= 0.6} / ((probX^{g= 0.6}  + (1-probX)^{g= 0.6})^(1/{g= 0.6})))  *({alpha=0.8}*(X^({alpha=0.8} -1)))*m) / ///
	( ///
	(probY^{g= 0.6} / ((probY^{g= 0.6}  + (1-probY)^{g= 0.6})^(1/{g= 0.6}))) *{alpha=0.8}*(Y^({alpha=0.8} -1)) + ///
	(probZ^{g= 0.6} / ((probZ^{g= 0.6}  + (1-probZ)^{g= 0.6})^(1/{g= 0.6}))) *{alpha=0.8}*(Z^({alpha=0.8} -1)) ///
	) ///  
	) ///
) ///
	) if series != 3 & mswitcher == 0	, clu(uniqid) 

log off 

/*** END ANALYSIS FOOTNOTE 60 and MIXTURE ***/

/*** BEGIN INDIVIDUAL ANALYSIS FOR SECTION 5.3 ***/

/* Individual Behavior */
capture drop temp
egen temp = mean(eqredmid) if valgroup == 3 & series == 1, by(uniqid)
capture drop val3series1 
egen val3series1 = mean(temp), by(uniqid)
capture drop temp
egen temp = mean(eqredmid) if valgroup == 3 & series == 2, by(uniqid)
capture drop val3series2 
egen val3series2 = mean(temp), by(uniqid)

capture drop temp
egen temp = mean(eqredmid) if valgroup == 21 & series == 1, by(uniqid)
capture drop val21series1 
egen val21series1 = mean(temp), by(uniqid)
capture drop temp
egen temp = mean(eqredmid) if valgroup == 21 & series == 2, by(uniqid)
capture drop val21series2 
egen val21series2 = mean(temp), by(uniqid)


capture drop temp
egen temp = mean(eqredmid) if valgroup == 39 & series == 1, by(uniqid)
capture drop val39series1 
egen val39series1 = mean(temp), by(uniqid)
capture drop temp
egen temp = mean(eqredmid) if valgroup == 39 & series == 2, by(uniqid)
capture drop val39series2 
egen val39series2 = mean(temp), by(uniqid)

capture drop temp
gen temp = val3series1 - val21series1
capture drop temp2
gen temp2 = val21series1 - val39series1

capture drop nonmonotonic1
gen nonmonotonic1 = 0
replace nonmonotonic1 = 1 if temp > 0.25 & temp2 < -0.25 & temp != . & temp2 != .
tab nonmonotonic1 if task ==1 & mswitcher == 0


capture drop temp
gen temp = val3series2 - val21series2
capture drop temp2
gen temp2 = val21series2 - val39series2

capture drop nonmonotonic2
gen nonmonotonic2 = 0
replace nonmonotonic2 = 1 if temp > 0.25 & temp2 < -0.25 & temp != . & temp2 != .
tab nonmonotonic2 if task ==1 & mswitcher == 0

log on
/* Non-Monotonicities in Modified Equalizing Reductions */
tab nonmonotonic1 nonmonotonic2 if task ==1 & mswitcher == 0

log off

/*** END INDIVIDUAL ANALYSIS FOR SECTION 5.3 ***/
