/* Cumulative Prospect Theory Implication */
/* Bernheim - Sprenger */
/* dosplitprobability.do */

/* Read in Data */
clear
use "`c(pwd)'/Data/splitprobability.dta"


/*** BEGIN FIGURE 6 ****/
log on
/* Estimate CPT on Certainty Equivalents for Binary Lotteries in Split Experiment */ 
nl (valprop = (p^{g= 0.6} / (p^{g= 0.6}  + (1-p)^{g= 0.6})^(1/{g= 0.6}))^(1/{a=0.8}) ) if cpttasks ==1 & mswitch != 1, clu(uniqid)
test _b[/g] = 1
test _b[/a]=1
log off
capture drop temp
predict temp
capture drop valmodel
gen valmodel = temp*25
 
 
/* Build Up CPT Probability Distortions */
nlcom (p30hat: 0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))) ///
(p40hat: 0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ///
(p60hat: 0.60^(_b[g:_cons])/((0.60^(_b[g:_cons]) + 0.40^(_b[g:_cons]))^(1/_b[g:_cons]))) ///
(p70hat: 0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) ///
(a: _b[a:_cons]) ///
, post 
 
/* Build Up Certainty Equivalents for Split Probabilities*/ 
nlcom (splitlow0:   (_b[p40hat]*30^_b[a] + (1 - _b[p40hat])*20^_b[a])^(1/_b[a])) ///
(splitlow05:   (_b[p40hat]*30^_b[a] + (_b[p70hat] - _b[p40hat])*20.5^_b[a]  + (1 - _b[p70hat])*19.5^_b[a] )^(1/_b[a])) ///
(splitlow1:   (_b[p40hat]*30^_b[a] + (_b[p70hat] - _b[p40hat])*21^_b[a]  + (1 - _b[p70hat])*19^_b[a] )^(1/_b[a])) ///
(splitlow2:   (_b[p40hat]*30^_b[a] + (_b[p70hat] - _b[p40hat])*22^_b[a]  + (1 - _b[p70hat])*18^_b[a] )^(1/_b[a])) ///
(splitlow3:   (_b[p40hat]*30^_b[a] + (_b[p70hat] - _b[p40hat])*23^_b[a]  + (1 - _b[p70hat])*17^_b[a] )^(1/_b[a])) ///
(splithigh0:   (_b[p60hat]*30^_b[a] + (1 - _b[p60hat])*20^_b[a])^(1/_b[a])) ///
(splithigh05:   (_b[p30hat]*30.5^_b[a] + (_b[p60hat] - _b[p30hat])*29.5^_b[a]  + (1 - _b[p60hat])*20^_b[a] )^(1/_b[a])) ///
(splithigh1:   (_b[p30hat]*31^_b[a] + (_b[p60hat] - _b[p30hat])*29^_b[a]  + (1 - _b[p60hat])*20^_b[a] )^(1/_b[a])) ///
(splithigh2:   (_b[p30hat]*32^_b[a] + (_b[p60hat] - _b[p30hat])*28^_b[a]  + (1 - _b[p60hat])*20^_b[a] )^(1/_b[a])) ///
(splithigh3:   (_b[p30hat]*33^_b[a] + (_b[p60hat] - _b[p30hat])*27^_b[a]  + (1 - _b[p60hat])*20^_b[a] )^(1/_b[a])) ///
, post

/* Generate Variable with Predicted Value */ 
capture drop splitmod
gen splitmod = .
replace splitmod = _b[splitlow0]  if splitval == 0 & splitlow == 1
replace splitmod = _b[splitlow05]  if splitval == 0.5 & splitlow == 1
replace splitmod = _b[splitlow1]  if splitval == 1 & splitlow == 1
replace splitmod = _b[splitlow2]  if splitval == 2 & splitlow == 1
replace splitmod = _b[splitlow3]  if splitval == 3 & splitlow == 1
replace splitmod = _b[splithigh0]  if splitval == 0 & splithigh == 1
replace splitmod = _b[splithigh05]  if splitval == 0.5 & splithigh == 1
replace splitmod = _b[splithigh1]  if splitval == 1 & splithigh == 1
replace splitmod = _b[splithigh2]  if splitval == 2 & splithigh == 1
replace splitmod = _b[splithigh3]  if splitval == 3 & splithigh == 1 


/* Estimate1979  PT from Certainty Equivalents (Identical Estimation to CPT) */
nl (valprop = (p^{g= 0.6} / (p^{g= 0.6}  + (1-p)^{g= 0.6})^(1/{g= 0.6}))^(1/{a=0.8}) ) if cpttasks ==1 & mswitch != 1, clu(uniqid)
test _b[/g] = 1
test _b[/a]=1
capture drop temp
predict temp
capture drop valmodel
gen valmodel = temp*25
 
 
/* Build Up 1979 PT Probability Distortions */
nlcom (p30hat: 0.30^(_b[g:_cons])/((0.30^(_b[g:_cons]) + 0.70^(_b[g:_cons]))^(1/_b[g:_cons]))) ///
(p40hat: 0.40^(_b[g:_cons])/((0.40^(_b[g:_cons]) + 0.60^(_b[g:_cons]))^(1/_b[g:_cons]))) ///
(p60hat: 0.60^(_b[g:_cons])/((0.60^(_b[g:_cons]) + 0.40^(_b[g:_cons]))^(1/_b[g:_cons]))) ///
(p70hat: 0.70^(_b[g:_cons])/((0.70^(_b[g:_cons]) + 0.30^(_b[g:_cons]))^(1/_b[g:_cons]))) ///
(a: _b[a:_cons]) ///
, post 
 
/* Build Up Certainty Equivalents for Split Probabilities 1979 PT */ 
nlcom (splitlow0:   (_b[p40hat]*30^_b[a] + (1 - _b[p40hat])*20^_b[a])^(1/_b[a])) ///
(splitlow05:   (_b[p40hat]*30^_b[a] + _b[p30hat]*20.5^_b[a]  + _b[p30hat]*19.5^_b[a] )^(1/_b[a])) ///
(splitlow1:   (_b[p40hat]*30^_b[a] + _b[p30hat]*21^_b[a]  + _b[p30hat]*19^_b[a] )^(1/_b[a])) ///
(splitlow2:   (_b[p40hat]*30^_b[a] + _b[p30hat]*22^_b[a]  + _b[p30hat]*18^_b[a] )^(1/_b[a])) ///
(splitlow3:   (_b[p40hat]*30^_b[a] + _b[p30hat]*23^_b[a]  + _b[p30hat]*17^_b[a] )^(1/_b[a])) ///
(splithigh0:   (_b[p60hat]*30^_b[a] + (1 - _b[p60hat])*20^_b[a])^(1/_b[a])) ///
(splithigh05:   (_b[p30hat]*30.5^_b[a] + _b[p30hat]*29.5^_b[a]  + _b[p40hat]*20^_b[a] )^(1/_b[a])) ///
(splithigh1:    (_b[p30hat]*31^_b[a] + _b[p30hat]*29^_b[a]  + _b[p40hat]*20^_b[a] )^(1/_b[a])) ///
(splithigh2:    (_b[p30hat]*32^_b[a] + _b[p30hat]*28^_b[a]  + _b[p40hat]*20^_b[a] )^(1/_b[a])) ///
(splithigh3:    (_b[p30hat]*33^_b[a] + _b[p30hat]*27^_b[a]  + _b[p40hat]*20^_b[a] )^(1/_b[a])) ///
, post

/* Generate Variable with Predicted Value */ 
 capture drop splitmod2
gen splitmod2 = .
replace splitmod2 = _b[splitlow0]  if splitval == 0 & splitlow == 1
replace splitmod2 = _b[splitlow05]  if splitval == 0.5 & splitlow == 1
replace splitmod2 = _b[splitlow1]  if splitval == 1 & splitlow == 1
replace splitmod2 = _b[splitlow2]  if splitval == 2 & splitlow == 1
replace splitmod2 = _b[splitlow3]  if splitval == 3 & splitlow == 1
replace splitmod2 = _b[splithigh0]  if splitval == 0 & splithigh == 1
replace splitmod2 = _b[splithigh05]  if splitval == 0.5 & splithigh == 1
replace splitmod2 = _b[splithigh1]  if splitval == 1 & splithigh == 1
replace splitmod2 = _b[splithigh2]  if splitval == 2 & splithigh == 1
replace splitmod2 = _b[splithigh3]  if splitval == 3 & splithigh == 1 
 

 
 /* Panel A: Certainty Equivalents and PT/CPT Model Fit */
xi: intreg vallow valhigh i.qnum if cpttasks == 1 & mswitch != 1  , clu(uniqid)
capture drop valhat
predict valhat if cpttasks == 1
capture drop valhatse
predict valhatse if cpttasks == 1, stdp 
capture drop valhatlow
gen valhatlow = valhat - 1.96*valhatse
capture drop valhathigh
gen valhathigh = valhat + 1.96*valhatse

twoway   (scatter valhat p if cpttasks == 1, sort)   (scatteri 0 0 25 1, recast(line) lpattern(solid))  (rcap valhatlow valhathigh p if cpttasks == 1) (line valmodel p ,sort lpattern(dash) lcolor(black)) (scatteri 0 0  2.587533 0.05, recast(line) lpattern(dash) lcolor(black))  (scatteri   20.73924  0.95 25 1, recast(line) lpattern(dash) lcolor(black))   ///
if uniqid == 1, xtitle("Chance of $25") ytitle("Certainty Equivalent") legend(order(1 "CE"    2 "Risk Neutral" 3 "95% CI" 4 "CPT Model") row(4) ) scheme(s2mono) title("Panel A: Certainty Equivalents") 
graph save "`c(pwd)'/Output/panelA.gph", replace


/* Panel B: Actual Split Probability Certainty Equivalents and Predicted Values from PT/CPT */
intreg vallow valhigh i.qnum if splittasks == 1 & mswitch != 1 , clu(uniqid)
capture drop valhat
predict valhat if splittasks == 1
capture drop valhatse
predict valhatse if splittasks == 1, stdp 
capture drop valhatlow
gen valhatlow = valhat - 1.96*valhatse
capture drop valhathigh
gen valhathigh = valhat + 1.96*valhatse


/* Check For Differences Across Presentation Style */
xi: intreg vallow valhigh i.splitval0low*i.version i.splitval0high*i.version if splittasks == 1 & mswitch != 1 & splitval == 0, clu(uniqid)
capture drop valhat0
predict valhat0 if e(sample)

twoway  (rcap valhatlow valhathigh splitval) (connected valhat splitval if splitlow==1, sort) (connected valhat splitval if splithigh==1,sort)  (line splitmod splitval if splitlow==1, sort lpattern(solid) lcolor(black)) (line splitmod splitval if splithigh==1, sort lpattern(solid) lcolor(black))   ///
(line splitmod2 splitval if splitlow==1, sort lpattern(dash) lcolor(black)) (line splitmod2 splitval if splithigh==1, sort lpattern(dash) lcolor(black)) ///
(scatter valhat0 splitval if version == 1 & splitlow == 1, mcolor(red) msymbol(diamond_hollow)) (scatter valhat0 splitval if version == 2 & splitlow == 1, mcolor(blue) msymbol(diamond_hollow)) ///
(scatter valhat0 splitval if version == 1 & splithigh == 1, mcolor(red) msymbol(square_hollow)) (scatter valhat0 splitval if version == 2 & splithigh == 1, mcolor(blue) msymbol(square_hollow)) ///
 if (uniqid == 2 | uniqid ==4), xtitle("Splitting Value, epsilon") ytitle("Certainty Equivalent" ) legend(order(2 "Split Low, $20"  3 "Split High, $30"  1 "95% CI" 4 "CPT Prediction" 6 "PT Prediction" 8 "Version 60-40" 9 "Version 30-30-40" ) row(4) )  ///
 scheme(s2mono) title("Panel B: Split Probabilities") ylabel(23(2)27)
graph save "`c(pwd)'/Output/panelB.gph", replace
 
 
graph combine "`c(pwd)'/Output/panelA.gph" "`c(pwd)'/Output/panelB.gph", scheme(s2mono) xsize(15) ysize(8)
graph export "`c(pwd)'/Output/splitprobcombined.pdf", replace 

/*** END FIGURE 6 ****/


/*** BEGIN ADDITIONAL ANALYSIS OF SECTION 6 ****/
xi: intreg vallow valhigh i.splitval*i.splithigh if splittasks == 1 & mswitch != 1 , clu(uniqid)

log on
/* Difference Between epsilon=0 and epsilong =0.5 in Split Probability Experiment */
lincom  _Isplitval_2 
 ttest difflow1 = 0 if qnum ==1 & mswitch != 1
  ttest difflow1 = 0 if qnum ==1 & mswitch != 1 & stanford == 0
   ttest difflow1 = 0 if qnum ==1 & mswitch != 1 & stanford == 1
 log off

 /*** END ADDITIONAL ANALYSIS OF SECTION 6 ****/
